``ExposoGraph.viewer_dash``
===========================

Advanced Dash Cytoscape viewer helpers, including filter application,
detail-panel payload generation, app creation, and notebook/app launch hooks.

.. automodule:: ExposoGraph.viewer_dash
   :members:
   :undoc-members:
